..
   This is an autogenerated file from processors.rst

avatars.processors.RelativeDifferenceProcessor
==============================================

.. autoclass:: avatars.processors.RelativeDifferenceProcessor
   :members: